@@ -66,7 +66,6 @@ import org.eclipse.jdt.core.dom.rewrite.ListRewrite;
 import org.eclipse.jdt.core.refactoring.CompilationUnitChange;
 
 import org.eclipse.jdt.internal.corext.codemanipulation.ContextSensitiveImportRewriteContext;
-import org.eclipse.jdt.internal.corext.codemanipulation.StubUtility;
 import org.eclipse.jdt.internal.corext.dom.ASTNodes;
 import org.eclipse.jdt.internal.corext.dom.CodeScopeBuilder;
 import org.eclipse.jdt.internal.corext.fix.LinkedProposalModel;
@@ -75,6 +74,7 @@ import org.eclipse.jdt.internal.corext.refactoring.RefactoringCoreMessages;
 import org.eclipse.jdt.internal.corext.refactoring.util.RefactoringASTParser;
 import org.eclipse.jdt.internal.corext.refactoring.util.ResourceUtil;
 import org.eclipse.jdt.internal.corext.refactoring.util.SelectionAwareSourceRangeComputer;
+import org.eclipse.jdt.internal.core.manipulation.StubUtility;
 import org.eclipse.jdt.internal.core.manipulation.dom.ASTResolving;
 import org.eclipse.jdt.internal.core.manipulation.util.Strings;
 
@@ -318,6 +318,16 @@ public class SurroundWithTryCatchRefactoring extends Refactoring {
 					VariableDeclarationFragment fragment= iter.next();
 					fragment.setInitializer(null);
 				}
+
+				// "var" type cannot have null initializer, so change to inferred type
+				if (ASTNodes.isVarType(statement, fRootNode)) {
+					ITypeBinding binding= statement.getType().resolveBinding();
+					if (binding != null) {
+						Type varType= fImportRewrite.addImport(binding, getAST(), context, TypeLocation.LOCAL_VARIABLE);
+						copy.setType(varType);
+					}
+				}
+
 				CompilationUnit root= (CompilationUnit)statement.getRoot();
 				int extendedStart= root.getExtendedStartPosition(statement);
 				// we have a leading comment and the comment is covered by the selection
