@@ -20,6 +20,7 @@
  *     				Warning option for bug 410218 - https://bugs.eclipse.org/461999
  *     Gábor Kövesdán - Contribution for Bug 350000 - [content assist] Include non-prefix matches in auto-complete suggestions
  *     Jesper S Møller - Contributions for bug 529432 - Allow JDT UI to target Java 10
+ *     Angelo Zerr <angelo.zerr@gmail.com> - [CodeMining] Provide Java References/Implementation CodeMinings - Bug 529127
  *******************************************************************************/
 package org.eclipse.jdt.internal.ui.preferences;
 
@@ -167,6 +168,7 @@ public final class PreferencesMessages extends NLS {
 	public static String JavaEditorPreferencePage_highlightEnclosingBrackets;
 	public static String JavaEditorPreferencePage_highlightMatchingBracket;
 	public static String JavaEditorPreferencePage_insertSingleProposalsAutomatically;
+	public static String JavaEditorPreferencePage_disableCompletionProposalTriggerChars;
 	public static String JavaEditorPreferencePage_showOnlyProposalsVisibleInTheInvocationContext;
 	public static String JavaEditorPreferencePage_presentProposalsInAlphabeticalOrder;
 	public static String JavaEditorPreferencePage_coloring_element;
@@ -309,7 +311,7 @@ public final class PreferencesMessages extends NLS {
 	public static String AppearancePreferencePage_pkgNamePatternAbbreviateEnable_label;
 	public static String AppearancePreferencePage_pkgNamePatternAbbreviate_label;
 	public static String AppearancePreferencePage_showMembersInPackagesView;
-	public static String AppearancePreferencePage_decorateTestCodeContainerIcons;	
+	public static String AppearancePreferencePage_decorateTestCodeContainerIcons;
 	public static String AppearancePreferencePage_stackViewsVerticallyInTheJavaBrowsingPerspective;
 	public static String AppearancePreferencePage_note;
 	public static String AppearancePreferencePage_preferenceOnlyEffectiveForNewPerspectives;
@@ -377,6 +379,7 @@ public final class PreferencesMessages extends NLS {
 	public static String JavaBuildConfigurationBlock_pb_output_overlapping_with_source_label;
 	public static String JavaBuildConfigurationBlock_pb_strictly_compatible_jre_not_available_label;
 	public static String JavaBuildConfigurationBlock_pb_compiler_compliance_does_not_match_jre_label;
+	public static String JavaBuildConfigurationBlock_pb_main_only_project_has_test_only_dependency_label;
 	public static String JavaBuildConfigurationBlock_empty_input;
 	public static String JavaBuildConfigurationBlock_invalid_input;
 	public static String JavaBuildConfigurationBlock_filter_invalidsegment_error;
@@ -824,6 +827,7 @@ public final class PreferencesMessages extends NLS {
 	public static String ComplianceConfigurationBlock_version18;
 	public static String ComplianceConfigurationBlock_version9;
 	public static String ComplianceConfigurationBlock_version10;
+	public static String ComplianceConfigurationBlock_version_11;
 	public static String ComplianceConfigurationBlock_versionCLDC11;
 	public static String ComplianceConfigurationBlock_src_greater_compliance;
 	public static String ComplianceConfigurationBlock_classfile_greater_compliance;
@@ -877,4 +881,14 @@ public final class PreferencesMessages extends NLS {
 	public static String FilteredPreferencesTree_expandAll_tooltip;
 	public static String FilterTextControl_Clear;
 	public static String FilterTextControl_ClearFilterField;
+
+	public static String JavaEditorCodeMiningConfigurationBlock_common_description;
+	public static String JavaEditorCodeMiningConfigurationBlock_enableCodeMining_label;
+	public static String JavaEditorCodeMiningConfigurationBlock_showCodeMining_atLeastOne_label;
+	public static String JavaEditorCodeMiningConfigurationBlock_section_general;
+	public static String JavaEditorCodeMiningConfigurationBlock_showReferences_label;
+	public static String JavaEditorCodeMiningConfigurationBlock_showReferences_onTypes_label;
+	public static String JavaEditorCodeMiningConfigurationBlock_showReferences_onFields_label;
+	public static String JavaEditorCodeMiningConfigurationBlock_showReferences_onMethods_label;
+	public static String JavaEditorCodeMiningConfigurationBlock_showImplementations_label;
 }
