@@ -183,13 +183,6 @@ final class FormatterMessages extends NLS {
 	public static String FormatterModifyDialog_newLines_pref_before_else_statements;
 	public static String FormatterModifyDialog_newLines_pref_before_finally_statements;
 	public static String FormatterModifyDialog_newLines_pref_before_while_in_do_statements;
-	public static String FormatterModifyDialog_newLines_pref_empty_annotation_decl;
-	public static String FormatterModifyDialog_newLines_pref_empty_anonymous_class_body;
-	public static String FormatterModifyDialog_newLines_pref_empty_block;
-	public static String FormatterModifyDialog_newLines_pref_empty_class_body;
-	public static String FormatterModifyDialog_newLines_pref_empty_enum_constant;
-	public static String FormatterModifyDialog_newLines_pref_empty_enum_declaration;
-	public static String FormatterModifyDialog_newLines_pref_empty_method_body;
 	public static String FormatterModifyDialog_newLines_pref_empty_statement;
 	public static String FormatterModifyDialog_newLines_pref_end_of_file;
 	public static String FormatterModifyDialog_newLines_pref_enum_constants;
@@ -202,6 +195,17 @@ final class FormatterMessages extends NLS {
 	public static String FormatterModifyDialog_newLines_pref_keep_simple_if_on_one_line;
 	public static String FormatterModifyDialog_newLines_pref_keep_simple_while_body_on_one_line;
 	public static String FormatterModifyDialog_newLines_pref_keep_then_on_same_line;
+	public static String FormatterModifyDialog_newLines_pref_keep_annotation_declaration_on_one_line;
+	public static String FormatterModifyDialog_newLines_pref_keep_anonymous_type_declaration_on_one_line;
+	public static String FormatterModifyDialog_newLines_pref_keep_code_block_on_one_line;
+	public static String FormatterModifyDialog_newLines_pref_keep_enum_constant_declaration_on_one_line;
+	public static String FormatterModifyDialog_newLines_pref_keep_enum_declaration_on_one_line;
+	public static String FormatterModifyDialog_newLines_pref_keep_if_then_body_block_on_one_line;
+	public static String FormatterModifyDialog_newLines_pref_keep_lambda_body_block_on_one_line;
+	public static String FormatterModifyDialog_newLines_pref_keep_loop_body_block_on_one_line;
+	public static String FormatterModifyDialog_newLines_pref_keep_method_body_on_one_line;
+	public static String FormatterModifyDialog_newLines_pref_keep_simple_getter_setter_on_one_line;
+	public static String FormatterModifyDialog_newLines_pref_keep_type_declaration_on_one_line;
 	public static String FormatterModifyDialog_newLines_pref_local_variables;
 	public static String FormatterModifyDialog_newLines_pref_methods;
 	public static String FormatterModifyDialog_newLines_pref_packages;
@@ -209,11 +213,16 @@ final class FormatterMessages extends NLS {
 	public static String FormatterModifyDialog_newLines_pref_type_annotations;
 	public static String FormatterModifyDialog_newLines_pref_types;
 	public static String FormatterModifyDialog_newLines_tree_after_annotations;
-	public static String FormatterModifyDialog_newLines_tree_between_empty_braces;
 	public static String FormatterModifyDialog_newLines_tree_control_statements;
 	public static String FormatterModifyDialog_newLines_tree_if_else;
+	public static String FormatterModifyDialog_newLines_tree_keep_braced_code_on_one_line;
 	public static String FormatterModifyDialog_newLines_tree_new_lines;
 	public static String FormatterModifyDialog_newLines_tree_simple_loops;
+	public static String FormatterModifyDialog_newLines_val_one_line_always;
+	public static String FormatterModifyDialog_newLines_val_one_line_if_empty;
+	public static String FormatterModifyDialog_newLines_val_one_line_if_single_item;
+	public static String FormatterModifyDialog_newLines_val_one_line_never;
+	public static String FormatterModifyDialog_newLines_val_one_line_preserve;
 	public static String FormatterModifyDialog_offOn_description;
 	public static String FormatterModifyDialog_offOn_error_endsWithWhitespace;
 	public static String FormatterModifyDialog_offOn_error_startsWithWhitespace;
