@@ -102,7 +102,9 @@ public final class CorrectionMessages extends NLS {
 	public static String ReorgCorrectionsSubProcessor_addcp_variable_description;
 	public static String ReorgCorrectionsSubProcessor_addcp_library_description;
 	public static String LocalCorrectionsSubProcessor_surroundwith_trycatch_description;
+	public static String LocalCorrectionsSubProcessor_surroundwith_trycatch_var_description;
 	public static String LocalCorrectionsSubProcessor_surroundwith_trymulticatch_description;
+	public static String LocalCorrectionsSubProcessor_surroundwith_trymulticatch_var_description;
 	public static String LocalCorrectionsSubProcessor_add_default_case_description;
 	public static String LocalCorrectionsSubProcessor_add_missing_cases_description;
 	public static String LocalCorrectionsSubProcessor_addthrows_description;
@@ -295,6 +297,10 @@ public final class CorrectionMessages extends NLS {
 	public static String QuickAssistProcessor_splitdeclaration_description;
 	public static String QuickAssistProcessor_joindeclaration_description;
 	public static String QuickAssistProcessor_add_inferred_lambda_parameter_types;
+	public static String QuickAssistProcessor_replace_var_with_inferred_lambda_parameter_types;
+	public static String QuickAssistProcessor_add_var_lambda_parameter_types;
+	public static String QuickAssistProcessor_replace_lambda_parameter_types_with_var;
+	public static String QuickAssistProcessor_remove_lambda_parameter_types;
 	public static String QuickAssistProcessor_addfinallyblock_description;
 	public static String QuickAssistProcessor_addelseblock_description;
 	public static String QuickAssistProcessor_addParenthesesInLambda;
@@ -391,6 +397,8 @@ public final class CorrectionMessages extends NLS {
 	public static String QuickAssistProcessor_extractmethod_description;
 	public static String QuickAssistProcessor_move_exception_to_separate_catch_block;
 	public static String QuickAssistProcessor_move_exceptions_to_separate_catch_block;
+	public static String QuickAssistProcessor_create_new_junit_test_case;
+	public static String QuickAssistProcessor_create_new_junit_test_case_desc;
 	public static String SuppressWarningsSubProcessor_suppress_warnings_label;
 	public static String ReorgCorrectionsSubProcessor_accessrules_description;
 	public static String ReorgCorrectionsSubProcessor_project_seup_fix_description;
