@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -64,7 +64,7 @@ import org.eclipse.jdt.core.JavaConventions;
 import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.core.JavaModelException;
 
-import org.eclipse.jdt.internal.corext.codemanipulation.StubUtility;
+import org.eclipse.jdt.internal.core.manipulation.StubUtility;
 import org.eclipse.jdt.internal.corext.javadoc.JavaDocCommentReader;
 import org.eclipse.jdt.internal.corext.util.InfoFilesUtil;
 import org.eclipse.jdt.internal.corext.util.JavaConventionsUtil;
@@ -134,7 +134,7 @@ public class NewPackageWizardPage extends NewContainerWizardPage {
 
 		PackageFieldAdapter adapter= new PackageFieldAdapter();
 
-		fPackageDialogField= new StringDialogField();
+		fPackageDialogField= new StringDialogField(); 
 		fPackageDialogField.setDialogFieldListener(adapter);
 		fPackageDialogField.setLabelText(NewWizardMessages.NewPackageWizardPage_package_label);
 
@@ -244,7 +244,7 @@ public class NewPackageWizardPage extends NewContainerWizardPage {
 	 * Sets the focus to the package name input field.
 	 */
 	protected void setFocus() {
-		fPackageDialogField.setFocus();
+		fPackageDialogField.setFocus(false);
 	}
 
 
